@@ -79,7 +79,7 @@ SEXP sample_beta(SEXP n, SEXP pL, SEXP XL, SEXP xL2, SEXP bL, SEXP e, SEXP varBj
 
     for(j=0; j<cols;j++)
     {
-          xj=pXL+j*rows;
+          xj=pXL+(long long)j*rows;
           b=pbL[j];
           //F77_NAME(daxpy)(&rows, &b,xj,&inc, pe, &inc);
           rhs=F77_NAME(ddot)(&rows,xj,&inc,pe,&inc)/sigma2e;
@@ -112,6 +112,87 @@ SEXP sample_beta(SEXP n, SEXP pL, SEXP XL, SEXP xL2, SEXP bL, SEXP e, SEXP varBj
       return(list);
 }
 
+SEXP sample_beta_lower_tri(SEXP n, SEXP pL, SEXP XL, SEXP xL2, SEXP bL, SEXP e, SEXP varB, SEXP varE, SEXP minAbsBeta)
+{
+    double *xj;
+    double *pXL, *pxL2, *pbL, *pe;
+    double b;
+    int inc=1;
+    double rhs,c, sigma2b, sigma2e, smallBeta;
+    int j, rows, cols;
+
+    SEXP list;	
+
+    GetRNGstate();
+	
+    rows=INTEGER_VALUE(n);
+    cols=INTEGER_VALUE(pL);
+    sigma2b=NUMERIC_VALUE(varB);
+    sigma2e=NUMERIC_VALUE(varE);
+    smallBeta=NUMERIC_VALUE(minAbsBeta);
+	
+    PROTECT(XL=AS_NUMERIC(XL));
+    pXL=NUMERIC_POINTER(XL);
+
+    PROTECT(xL2=AS_NUMERIC(xL2));
+    pxL2=NUMERIC_POINTER(xL2);
+
+    PROTECT(bL=AS_NUMERIC(bL));
+    pbL=NUMERIC_POINTER(bL);
+
+    PROTECT(e=AS_NUMERIC(e));
+    pe=NUMERIC_POINTER(e);
+
+    xj=pXL;
+
+    int r=rows;
+    double *pe1;
+    pe1=pe;
+
+    for(j=0; j<cols;j++)
+    {
+          
+          b=pbL[j];
+
+          rhs=F77_NAME(ddot)(&r,xj,&inc,pe1,&inc)/sigma2e;
+          rhs+=pxL2[j]*b/sigma2e;
+  	  c=pxL2[j]/sigma2e + 1.0/sigma2b;
+	  pbL[j]=rhs/c + sqrt(1.0/c)*norm_rand();
+
+          b-=pbL[j];
+          //b=-pbL[j];        
+
+          F77_NAME(daxpy)(&r, &b,xj,&inc, pe1,&inc);
+          
+          if(fabs(pbL[j])<smallBeta)
+          {
+             pbL[j]=smallBeta;
+          }
+          
+          //Update the pointer to covariates
+          xj+=rows-j;
+         
+          //Update the pointer to the error
+	  pe1+=1;
+
+          r-=1;
+
+      }
+        
+      // Creating a list with 2 vector elements:
+      PROTECT(list = allocVector(VECSXP, 2));
+      // attaching bL vector to list:
+      SET_VECTOR_ELT(list, 0, bL);
+      // attaching e vector to list:
+      SET_VECTOR_ELT(list, 1, e);
+
+      PutRNGstate();
+
+      UNPROTECT(5);
+
+      return(list);
+}
+
 
 
 /*
@@ -165,7 +246,7 @@ SEXP sample_beta_BB_BCp(SEXP n, SEXP p, SEXP X, SEXP x2, SEXP b, SEXP d, SEXP er
 
   for(j=0; j<cols; j++)
   {
-     xj=pX+j*rows;
+     xj=pX+(long long)j*rows;
      Xe=F77_NAME(ddot)(&rows,perror,&inc,xj,&inc);
 
      if(pd[j])
@@ -309,8 +390,8 @@ SEXP sample_beta_BB_BCp_groups(SEXP n, SEXP p, SEXP X, SEXP x2, SEXP b, SEXP d,
 
   for(j=0; j<cols; j++)
   {
-     xj=pX+j*rows;   //Pointer to the j-th column
-     xj2=pX2+j*ngroups; //Pointer to the sum of squares of the j-th column
+     xj=pX+(long long)j*rows;   //Pointer to the j-th column
+     xj2=pX2+(long long)j*ngroups; //Pointer to the sum of squares of the j-th column
      
 
      //Clean initialization
@@ -548,7 +629,7 @@ SEXP sample_beta_groups(SEXP n, SEXP pL, SEXP XL, SEXP xL2, SEXP bL, SEXP e, SEX
 
           c=0;
 
-          xj=pXL+j*rows;
+          xj=pXL+(long long)j*rows;
           b=pbL[j];
 
           //rhs=F77_NAME(ddot)(&rows,xj,&inc,pe,&inc)/sigma2e;
@@ -580,7 +661,7 @@ SEXP sample_beta_groups(SEXP n, SEXP pL, SEXP XL, SEXP xL2, SEXP bL, SEXP e, SEX
 
           //weighted_ddot(rows, xj, pe, g, rhs);
 
-          xj2=pXL2+j*ngroups;
+          xj2=pXL2+(long long)j*ngroups;
 
           for(k=0;k<ngroups;k++)
 	  {
